@@ -572,16 +572,17 @@ class SheetResult(Base):
 
     sheet_id = Column(ForeignKey('univer_sheet.sheet_id'), primary_key=True)
     sheet = relationship('Sheet')
-    subject_id = Column(ForeignKey('univer_subject.subject_id'), primary_key=True)
+    subject_id = Column(ForeignKey('univer_subject.subject_id'))
     subject = relationship('Subject')
-    teacher_id = Column(ForeignKey('univer_teacher.teacher_id'), primary_key=True)
+    teacher_id = Column(ForeignKey('univer_teacher.teacher_id'))
     teacher = relationship('Teacher')
     academ_year = Column(Integer)
     semester = Column('semestr', Integer)
-    student_id = relationship('univer_students.students_id', primary_key=True)
+    control = Column(Integer, primary_key=True)
+    student_id = Column(ForeignKey('univer_students.students_id'), primary_key=True)
     student = relationship('Student')
     result = Column(Float)
-    date_keep = Column(DateTime, primary_key=True)
+    date_keep = Column(DateTime)
     P_P = Column(Integer)
     n_seme = Column(Integer)
     mark_sheet_result = Column(Integer)
